add_info: Add meta-information to the data frame containing the input...

View source: R/add_info.R

add_infoR Documentation

Add meta-information to the data frame containing the input data

Description

This function adds meta-information of the input data within the data frame containing the input data.

Usage

add_info(df, info)

Arguments

df

Data frame containing the input data

info

String or Data frame with one row or Vector of length 1 showing additional information or id for the pollutant.

Value

This function returns a data frame with binding the input data with the info columns (info_ is added to the column names)

Author(s)

Alberto Castro & Axel Luyten


healthiar documentation built on March 12, 2026, 5:07 p.m.