View source: R/compile_input.R
| compile_input | R Documentation |
This function compiles the input data of the main function and calculates the population attributable fraction based on the input data (all in one data frame)
compile_input(input_args, is_lifetable)
input_args |
|
is_lifetable |
|
This function returns a data.frame with all input data together
Moreover, the data frame includes columns such as:
Attributable fraction
Health impact
Outcome metric
And many more.
Alberto Castro & Axel Luyten
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.