Learn R Programming

healthiar (version 0.2.3)

exdat_noise: Noise exposure in urban and rural regions in Norway

Description

This tibble contains noise exposure data from urban and rural regions in Norway.

Usage

data(exdat_noise)

Arguments

Format

exdat_noise

exposure_category

noise exposure range of the exposure category

exposure_mean

mean noise exposure in the exposure category

region

region for which exposure is valid

exposed

number of exposed persons

Author

Anette Kocbach Bolling & Vázquez Fernández