| exdat_ozone | R Documentation |
This tibble contains modelled ozone (O_3) exposure and chronic obstructive pulmonary disease (COPD) incidence data from the Germany in 2016.
data(exdat_ozone)
exdat_ozone
O_3
mean exposure level in the exposure category
unit of the exposure
proportion of the total population exposed to each exposure category
mortality due to chronic obstructive pulmonary disease (ICD-10 J40-44)
central relative risk estimate
lower 95% confidence interval bound of the relative risk estimate
upper 95% confidence interval bound of the relative risk estimate
exposure increment in \mu g/m^3 for which the relative risk estimates are valid
cutoff level below which no health effects are attributable to the exposure
shape of the exposure-response function
exposure type
source of the relative risk estimates
country
year of the data
Alberto Castro & Axel Luyten
Real-world data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.