| exdat_pm | R Documentation |
This tibble contains PM2.5 exposure and COPD incidence data from Switzerland.
data(exdat_pm)
exdat_pm
air pollutant of data set
population-weighted annual mean concentration
COPD incidence in the year of analysis
central relative risk estimate
lower 95% confidence interval bound of the relative risk estimate
upper 95% confidence interval bound of the relative risk estimate
exposure increment in \mu g/m^3 for which the relative risk estimates are valid
shape of the exposure-response function
cut-off value
source of the relative risk
DOI linking to the publication from which the relative risk was taken
year that the exposure and incidence data is from
Alberto Castro & Axel Luyten
Real-world data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.