exdat_pwm_2: Geospatial outlines and populations of the Brussels-Capital...

exdat_pwm_2R Documentation

Geospatial outlines and populations of the Brussels-Capital region (Belgium)

Description

This variable of class sf and data.frame contains the geospatial outlines and populations of municipalities in the Brussels-Capital region (Belgium).

Usage

data(exdat_pwm_2)

Format

exdat_pwm_2

code

NIS-codes (i.e. unique statistical code assigned to each geographic area in Belgium)

name

Dutch names of the municipalities

population

municipality populations

region

geographic position of each municipality (North, East, West, South) relative to Brussels (Center)

geom

geospatial outlines of the municipalities (MULTIPOLYGON)

Author(s)

Arno Pauwels

Real-world data


healthiar documentation built on March 12, 2026, 5:07 p.m.