View source: R/find_joining_columns.R
| find_joining_columns | R Documentation |
This function finds columns in two data frames that have same name and identical values (excluding exceptions).- The resulting joining columns are used to dplyr::x_join data frames and add the vector to by=.
find_joining_columns(df_1, df_2, except = NULL)
df_1 |
First |
df_2 |
Second |
except |
|
This function returns a vector of strings
Alberto Castro & Axel Luyten
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.