find_multi_value_col_names: Find columns with multiple values

View source: R/find_multi_value_col_names.R

find_multi_value_col_namesR Documentation

Find columns with multiple values

Description

This function find data frame or tibble column names with different values in their rows (i.e. not a unique value)

Usage

find_multi_value_col_names(df, group_col_names = NULL)

Arguments

df

Data frame or tibble containing the data

group_col_names

String vector that refers to the column names in df that serve as grouping columns.

Value

This function returns a string vector with the names of the columns with multiple values

Author(s)

Alberto Castro & Axel Luyten


healthiar documentation built on March 12, 2026, 5:07 p.m.