get_input_args: get_input_args

View source: R/get_input_args.R

get_input_argsR Documentation

get_input_args

Description

This function compiles the input data of the main function and calculates the population attributable fraction based on the input data (all in one data frame)

Usage

get_input_args(environment, call)

Value

This function returns a list with all input data together by argument

Author(s)

Alberto Castro & Axel Luyten


healthiar documentation built on March 12, 2026, 5:07 p.m.