| get_output | R Documentation |
This function distributes and store outputs by level of detail by aggregating or filtering impacts.
get_output(
input_args = NULL,
input_table = NULL,
intermediate_calculations = NULL,
results_raw
)
input_args |
|
input_table |
|
intermediate_calculations |
|
results_raw |
|
TBD. E.g. This function returns a data.frame with one row for each value of the
concentration-response function (i.e. central, lower and upper bound confidence interval.
Moreover, the data frame includes columns such as:
Attributable fraction
Health impact
Outcome metric
And many more.
Alberto Castro & Axel Luyten
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.