View source: R/get_pop_fraction.R
| get_pop_fraction | R Documentation |
This function calculates the population attributable fraction or potential impact fraction of a health outcome due to exposure to an environmental stressor
get_pop_fraction(rr_at_exp_1, rr_at_exp_2, prop_pop_exp_1, prop_pop_exp_2)
rr_at_exp_1 |
|
rr_at_exp_2 |
|
prop_pop_exp_1 |
|
prop_pop_exp_2 |
|
For more information about the equations used please see the function documentation of attribute_health.
This function returns a value corresponding to the population attributable fraction
Alberto Castro & Axel Luyten
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.