validate_input_attribute: Check the input_args data of attribute_master()

View source: R/validate_input_attribute.R

validate_input_attributeR Documentation

Check the input_args data of attribute_master()

Description

Check the input_args data in attribute_master() and provides specific warnings or errors if needed.

Usage

validate_input_attribute(input_args, is_lifetable)

Arguments

input_args

List with the argument names and values entered in the function.

is_lifetable

Boolean INTERNAL argument specifying if the life table approach is applied (TRUE) or not (FALSE)

Value

This function returns warning or error messages if needed.

Author(s)

Alberto Castro & Axel Luyten


healthiar documentation built on March 12, 2026, 5:07 p.m.