| add_info | R Documentation |
This function adds meta-information of the input data within the data frame containing the input data.
add_info(df, info)
df |
|
info |
|
This function returns a data frame with binding the input data with the info columns (info_ is added to the column names)
Alberto Castro & Axel Luyten
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.