Learn R Programming

healthiar (version 0.2.3)

add_info: Add meta-information to the data frame containing the input data

Description

This function adds meta-information of the input data within the data frame containing the input data.

Usage

add_info(df, info)

Value

This function returns a data frame with binding the input data with the info columns (info_ is added to the column names)

Arguments

df

Data frame containing the input data

info

String or Data frame with one row or Vector of length 1 showing additional information or id for the pollutant.

Author

Alberto Castro & Axel Luyten