This function adds meta-information of the input data within the data frame containing the input data.
add_info(df, info)This function returns a data frame with binding the input data with the info columns (info_ is added to the column names)
Data frame containing the input data
String or Data frame with one row or Vector of length 1 showing additional information or id for the pollutant.
Alberto Castro & Axel Luyten