Function arguments
age_group
The numeric values must refer to 1 year age groups, e.g. c(0:99). To convert multi-year/larger age groups to 1 year age groups use the function prepare_lifetable() (see its function documentation for more info).
bhd_central,bhd_lower,bhd_upper
Deaths per age must be inputted with 1 value per age (i.e. age group size = 1 year). There must be greater than or equal to 1 deaths per age to avoid issues during the calculation of survival probabilities.
population
The population data must be inputted with 1 value per age (i.e. age group size = 1 year). The values must be greater than or equal to 1 per age to avoid issues during the calculation of survival probabilities.
Mid-year population of year x can be approximated as the mean of either end-year populations of years x-1 and x or start-of-year populations of years x and x+1. For each age, the inputted values must be greater than or equal to 1 to avoid issues during the calculation of survival probabilities.
approach_newborns
If "with_newborns" is selected, it is assumed that for each year after the year of analysis n babies (population aged 0) are born.
time_horizon
Applicable for the following cases:
#'
For example, if 10 is entered one is interested in the impacts of exposure during the year of analysis and the next 9 years (= 10 years in total). Default value: length of the numeric vector specified in the age_group argument.
min_age, max_age
The min_age default value 30 implies that all adults aged 30 or older will be affected by the exposure; max_age analogeously specifies the age above which no health effects of the exposure are considered.
Conversion of multi-year to single year age groups
To convert multi-year/larger age groups to 1 year age groups use the function prepare_lifetable() and see its function documentation for more info.
Life table methodology
The life table methodology of attribute_lifetable() follows that of the WHO tool AirQ+, and is described in more detail by Miller & Hurley (2003, https://doi.org/10.1136/jech.57.3.200).
In short, two scenarios are compared: 1) a scenario with the exposure level specified in the function ("exposed scenario") and 2) a scenario with no exposure ("unexposed scenario"). First, the entry and mid-year populations of the (first) year of analysis in the unexposed scenario is determined using modified survival probabilities. Second, age-specific population projections using scenario-specific survival probabilities are done for both scenarios. Third, by subtracting the populations in the unexposed scenario from the populations in the exposed scenario the premature deaths/years of life lost attributable to the exposure are determined.
An expansive life table case study by Miller (2010) is available here: https://cleanair.london/app/uploads/CAL-098-Mayors-health-study-report-June-2010-1.pdf.
Determination of populations in the (first) year of analysis
The entry (i.e. start of year) populations in both scenarios is determined as follows:
$$entry\_population_{year_1} = midyear\_population_{year_1} + \frac{deaths_{year_1}}{2}$$
Exposed scenario The survival probabilities in the exposed scenario from start of year i to start of year i+1 are calculated as follows:
$$prob\_survival = \frac{midyear\_population_i - \frac{deaths_i}{2}}{midyear\_population_i + \frac{deaths_i}{2}}$$
Analogously, the probability of survival from start of year i to mid-year i:
$$prob\_survival\_until\_midyear = 1 - \frac{1 - prob\_survival}{2}$$
Unexposed scenario The survival probabilities in the unexposed scenario are calculated as follows:
First, the age-group specific hazard rate in the exposed scenario is calculated using the inputted age-specific mid-year populations and deaths.
$$hazard\_rate = \frac{deaths}{mid\_year\_population}$$
Second, the hazard rate is multiplied with the modification factor (\(= 1 - PAF\)) to obtain the age-specific hazard rate in the unexposed scenario.
$$hazard\_rate\_mod = hazard\_rate \times modification\_factor$$
Third, the the age-specific survival probabilities (from the start until the end in a given age group) in the unexposed scenario are calculated as follows (cf. Miller & Hurley 2003):
$$prob\_survival\_mod = \frac{2-hazard\_rate\_mod}{2+hazard\_rate\_mod}$$
Then the mid-year populations of the (first) year of analysis (year_1) in the unexposed scenario are determined as follows:
First, the survival probabilities from start of year i to mid-year i in the unexposed scenario is calculated as:
$$prob\_survival\_until\_midyear\_{mod} = 1 - \frac{1 - prob\_survival\_mod}{2}$$
Second, the mid-year populations of the (first) year of analysis (year_1) in the unexposed scenario is calculated:
$$midyear\_population\_unexposed_{year_1} = entry\_population_{year_1} \times prob\_survival\_until\_midyear_{mod}$$
Population projection
Using the age group-specific and scenario-specific survival probabilities calculated above, future populations of each age-group under each scenario are calculated.
Unexposed scenario The entry and mid-year population projections of in the exposed scenario is done as follows:
First, the entry population of year i+1 is calculated (which is the same as the end of year population of year i) by multiplying the entry population of year i and the modified survival probabilities.
$$entry\_population_{i+1} = entry\_population_i \times prob\_survival\_mod$$
Second, the mid-year population of year i+1 is calculated.
$$midyear\_population_{i+1} = entry\_population_{i+1} \times prob\_survival\_until\_midyear$$
Exposed scenario The population projections for the two possible options of approach_exposure ("single_year" and "constant") for the unexposed scenario are different. In the case of "single_year" exposure, the population projection for the years after the year of exposure is the same as in the unexposed scenario.
In the case of "constant" the population projection is done as follows:
First, the entry population of year i+1 is calculated (which is the same as the end of year population of year i) using the entry population of year i.
$$entry\_population_{i+1} = entry\_population_i \times prob\_survival$$
Second, the mid-year population of year i+1 is calculated.
$$midyear\_population_{i+1} = entry\_population_{i+1} \times prob\_survival\_until\_midyear$$
Conversion of alternative risk measures to relative risks
For conversion of hazard ratios and/or odds ratios to relative risks refer to https://doi.org/10.1111/biom.13197 and/or use the conversion tool for hazard ratios (https://ebm-helper.cn/en/Conv/HR_RR.html) and/or odds ratios (https://ebm-helper.cn/en/Conv/OR_RR.html).