View source: R/attribute_master.R
| attribute_master | R Documentation |
This INTERNAL function calculates the health impacts, mortality or morbidity, of an environmental stressor using a single value for baseline heath data, i.e. without life table.
attribute_master(
approach_risk = NULL,
exp_central,
exp_lower = NULL,
exp_upper = NULL,
cutoff_central = NULL,
cutoff_lower = NULL,
cutoff_upper = NULL,
pop_exp = NULL,
erf_eq_central = NULL,
erf_eq_lower = NULL,
erf_eq_upper = NULL,
rr_central = NULL,
rr_lower = NULL,
rr_upper = NULL,
rr_increment = NULL,
erf_shape = NULL,
bhd_central = NULL,
bhd_lower = NULL,
bhd_upper = NULL,
prop_pop_exp = NULL,
geo_id_micro = NULL,
geo_id_macro = NULL,
age_group = "all",
sex = "all",
population = NULL,
info = NULL,
dw_central = NULL,
dw_lower = NULL,
dw_upper = NULL,
duration_central = NULL,
duration_lower = NULL,
duration_upper = NULL,
is_lifetable = NULL,
health_outcome = NULL,
min_age = NULL,
max_age = NULL,
approach_newborns = NULL,
approach_exposure = NULL,
year_of_analysis = NULL,
time_horizon = NULL,
input_args = NULL
)
approach_risk |
|
exp_central, exp_lower, exp_upper |
|
cutoff_central, cutoff_lower, cutoff_upper |
|
pop_exp |
|
erf_eq_central, erf_eq_lower, erf_eq_upper |
|
rr_central, rr_lower, rr_upper |
|
rr_increment |
|
erf_shape |
|
bhd_central, bhd_lower, bhd_upper |
|
prop_pop_exp |
|
geo_id_micro, geo_id_macro |
|
age_group |
|
sex |
|
population |
|
info |
|
dw_central, dw_lower, dw_upper |
|
duration_central, duration_lower, duration_upper |
|
is_lifetable |
|
health_outcome |
|
min_age, max_age |
|
approach_newborns |
|
approach_exposure |
|
year_of_analysis |
|
time_horizon |
|
This function returns a list containing:
1) health_main (tibble) containing the main results;
impact (numeric column) attributable health burden/impact
pop_fraction (numeric column) population attributable fraction; only applicable in relative risk assessments
And many more
2) health_detailed (list) containing detailed (and interim) results.
input_args (list) containing all the argument inputs used in the background
input_table (tibble) containing the inputs after preparation
results_raw (tibble) containing results for all combinations of input (geo units, uncertainty, age and sex specific data...)
results_by_... (tibble) containing results stratified by each geographic unit, age or sex.
Alberto Castro & Axel Luyten
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.