View source: R/attribute_mod.R
| attribute_mod | R Documentation |
This function quantifies the attributable health impacts in a new scenario 2 as follows:
taking the input data of an existing scenario 1 (obtained using attribute_health()),
modifying some of these input data of scenario 1 for the scenario 2 and
calling in the background attribute_health() with the new data for scenario 2
attribute_mod(
output_attribute,
erf_shape = NULL,
rr_central = NULL,
rr_lower = NULL,
rr_upper = NULL,
rr_increment = NULL,
erf_eq_central = NULL,
erf_eq_lower = NULL,
erf_eq_upper = NULL,
exp_central = NULL,
exp_lower = NULL,
exp_upper = NULL,
prop_pop_exp = NULL,
pop_exp = NULL,
cutoff_central = NULL,
cutoff_lower = NULL,
cutoff_upper = NULL,
bhd_central = NULL,
bhd_lower = NULL,
bhd_upper = NULL,
geo_id_micro = NULL,
geo_id_macro = NULL,
age_group = NULL,
sex = NULL,
population = NULL,
info = NULL,
min_age = NULL,
max_age = NULL,
approach_exposure = NULL,
approach_newborns = NULL,
year_of_analysis = NULL
)
output_attribute |
|
erf_shape |
|
rr_central, rr_lower, rr_upper |
|
rr_increment |
|
erf_eq_central, erf_eq_lower, erf_eq_upper |
|
exp_central, exp_lower, exp_upper |
|
prop_pop_exp |
|
pop_exp |
|
cutoff_central, cutoff_lower, cutoff_upper |
|
bhd_central, bhd_lower, bhd_upper |
|
geo_id_micro, geo_id_macro |
|
age_group |
|
sex |
|
population |
|
info |
|
min_age, max_age |
|
approach_exposure |
|
approach_newborns |
|
year_of_analysis |
|
Methodology
This function calls in the background attribute_health(), which can use
the relative risk \insertCiteMurray2003_ehealthiar and absolute risk \insertCiteWHO2011_reporthealthiar.
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
This function returns a list containing:
1) health_main (tibble) containing the main results;
impact (numeric column) attributable health burden/impact
pop_fraction (numeric column) population attributable fraction; only applicable in relative risk assessments
And many more
2) health_detailed (list) containing detailed (and interim) results.
input_args (list) containing all the argument inputs used in the background
input_table (tibble) containing the inputs after preparation
results_raw (tibble) containing results for all combinations of input (geo units, uncertainty, age and sex specific data...)
results_by_... (tibble) containing results stratified by each geographic unit, age or sex.
Alberto Castro & Axel Luyten
Upstream: attribute_health, attribute_lifetable
Downstream: compare
# Goal: adjust an existing healthiar scenario and determine the health
# impacts in the modified scenario
## First create a scenario to be modified
scenario_A <- attribute_health(
exp_central = 8.85, # EXPOSURE 1
cutoff_central = 5,
bhd_central = 25000,
approach_risk = "relative_risk",
erf_shape = "log_linear",
rr_central = 1.118,
rr_increment = 10
)
scenario_A$health_main$impact # Attributable impact in scenario A
## Modify scenario (adjust exposure value)
scenario_B <- attribute_mod(
output_attribute = scenario_A,
exp_central = 6 # EXPOSURE 2
)
scenario_B$health_main$impact # Attributable impact in scenario B
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.