Create a scenario 2 by modifying an existing scenario 1 and determine attributable health impacts in it
Source:R/attribute_mod.R
attribute_mod.RdThis function quantifies the attributable health impacts in a new scenario 2 as follows:
taking the input data of an existing scenario 1 (obtained using
attribute_health()),modifying some of these input data of scenario 1 for the scenario 2 and
calling in the background
attribute_health()with the new data for scenario 2
Usage
attribute_mod(
output_attribute,
erf_shape = NULL,
rr_central = NULL,
rr_lower = NULL,
rr_upper = NULL,
rr_increment = NULL,
erf_eq_central = NULL,
erf_eq_lower = NULL,
erf_eq_upper = NULL,
exp_central = NULL,
exp_lower = NULL,
exp_upper = NULL,
prop_pop_exp = NULL,
pop_exp = NULL,
cutoff_central = NULL,
cutoff_lower = NULL,
cutoff_upper = NULL,
threshold = NULL,
bhd_central = NULL,
bhd_lower = NULL,
bhd_upper = NULL,
geo_id_micro = NULL,
geo_id_macro = NULL,
age_group = NULL,
sex = NULL,
population = NULL,
info = NULL,
min_age = NULL,
max_age = NULL,
approach_exposure = NULL,
approach_newborns = NULL,
year_of_analysis = NULL
)Arguments
- output_attribute
Listcontaining the output of the function attribute() for scenario 1.- erf_shape
String valuespecifying the exposure-response function shape to be assumed. Options (no default):"linear",log_linear","linear_log","log_log". Input exposure values must be expressed in same unit as the increment of the relative risk. The re-scale of the relative risk is unbounded above and users are responsible for the plausible range. Only applicable in RR pathways; not required iferf_eq_...argument(s) already specified.- rr_central, rr_lower, rr_upper
Numeric valuespecifying the central relative risk estimate and (optionally) the corresponding lower and upper 95% confidence interval bounds. Only applicable in RR pathways; not required iferf_eq_...argument(s) already specified.- rr_increment
Numeric valuespecifying the exposure increment for which the provided relative risk is valid. See Details for more info. Only applicable in RR pathways; not required iferf_eq_...argument(s) already specified.- erf_eq_central, erf_eq_lower, erf_eq_upper
Stringorfunctionspecifying the exposure-response function and (optionally) the corresponding lower and upper 95% confidence interval functions. See Details for more info. Required in AR pathways; in RR pathways required only ifrr_...argument(s) not specified.- exp_central, exp_lower, exp_upper
Numeric valueornumeric vectorspecifying the exposure level(s) to the environmental stressor and (optionally) the corresponding lower and upper bound of the 95% confidence interval. See Details for more info.- prop_pop_exp
Numeric valueornumeric vectorspecifying the population fraction(s) exposed for each exposure (category), i.e. the proportion of the total population that falls in each exposure category. Default: 1. The fractions do not have to add up to 1: the part of the population that they do not cover is treated as unexposed, i.e. it gets the relative risk of the reference level. E.g, in air pollution assessments everybody is usually exposed and the fractions add up to 1, whereas in noise assessments they typically add up to less than 1, because exposure is only reported above a given level. Accordingly,bhd_...must always refer to the total population. See Details for more info. Only applicable in RR pathways.- pop_exp
Numeric vectorspecifying the absolute size of the population(s) exposed to each exposure category. See Details for more info. Only applicable in AR pathways; always required.- cutoff_central, cutoff_lower, cutoff_upper
Numeric valuespecifying the exposure cut-off value, i.e. the exposure level below which no health impacts are quantified, and (optionally) the corresponding lower and upper 95% confidence interval bounds. Default: 0, or same value asthreshold, if it is entered. Ifcutoffis higher thanthreshold, the exposure-response function is truncated at the cut-off value. Expressed in the same unit as the exposure. See the vignette chapter Cut-off vs. threshold.- threshold
Numeric valuespecifying the effect threshold, i.e. the exposure level from which the exposure-response function starts to show an effect. It is the anchor of the curve and is therefore subtracted from the exposure. Default: same value as the cut-off. Expressed in the same unit as the exposure. See the vignette chapter Cut-off vs. threshold.- bhd_central, bhd_lower, bhd_upper
Numeric valueornumeric vectorproviding the baseline health data of the health outcome of interest in the study population and (optionally) the corresponding lower bound and the upper 95% confidence interval bounds. See Details for more info. Only applicable in RR pathways; always required.- geo_id_micro, geo_id_macro
Numeric vectororstring vectorproviding unique IDs of the geographic area considered in the assessment (geo_id_micro) and (optionally) providing higher-level IDs (geo_id_macro) to aggregate the geographic areas at. See Details for more info. Only applicable in assessments with multiple geographic units.- age_group
Numeric vectororstring vectorproviding the age groups considered in the assessment. In case of use inattribute_lifetable)(), it must be anumericand contain single year age groups. See Details for more info. Optional argument forattribute_health(); needed forattribute_lifetable().- sex
Numeric vectororstring vectorspecifying the sex of the groups considered in the assessment.Optional argument.- population
Numeric vectorFor attribute_lifetable(), it is an obligatory argument specifying the mid-year populations per age (i.e. age group size = 1 year) for the (first) year of analysis.For attribute_health()it is an optional argument which specifies the population used to calculate attributable impacts rate per 100 000 population. See Details for more info.- info
String,data frameortibbleproviding information about the assessment. This will be added to the results table as column(s) keeping the name(s) that you entered with the prefixinfo_(e.g. a columneducationbecomesinfo_education) if adata frameis entered, or as one single column calledinfoif a vector is entered. These additional columns can be used to further stratify the analysis in a secondary step. Optional argument.- min_age, max_age
Numeric valuespecifying the minimum and maximum age for which the exposure will affect the exposed population, respectively. See Details for more info.- approach_exposure
Stringspecifying whether exposure is constant or only in one year. Options:"single_year"(default),"constant".- approach_newborns
Stringspecifying whether newborns are to be considered in the years after the year of analysis or not. Options:"without_newborns"(default),"with_newborns". See Details for more info.- year_of_analysis
Numeric valueproviding the first with exposure to the environmental stressor.
Value
This function returns a list containing:
1) health_main (tibble) containing the main results;
impact(numericcolumn) attributable health burden/impactpop_fraction(numericcolumn) population attributable fraction; only applicable in relative risk assessmentsAnd many more
2) health_detailed (list) containing detailed (and interim) results.
input_args(list) containing all the argument inputs used in the backgroundinput_table(tibble) containing the inputs after preparationresults_raw(tibble) containing results for all combinations of input (geo units, uncertainty, age and sex specific data...)results_by_...(tibble) containing results stratified by each geographic unit, age or sex.
Details
Methodology
This function calls in the background attribute_health(), which can use
the relative risk (Murray et al. 2003)
and absolute risk (WHO 2011)
.
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
References
Murray CJ, Ezzati M, Lopez AD, Rodgers A, Hoorn SV (2003).
“Comparative risk assessment: conceptual framework and design.”
Epidemiology, 14(4), 447-458.
doi:10.1186/1478-7954-1-1
.
WHO (2011).
“Burden of disease from environmental noise: Quantification of healthy life years lost in Europe.”
World Health Organization.
https://www.who.int/publications/i/item/burden-of-disease-from-environmental-noise-quantification-of-healthy-life-years-lost-in-europe.
See also
Upstream:
attribute_health,attribute_lifetableDownstream:
compare
Examples
# Goal: adjust an existing healthiar scenario and determine the health
# impacts in the modified scenario
## First create a scenario to be modified
scenario_A <- attribute_health(
exp_central = 8.85, # EXPOSURE 1
cutoff_central = 5,
bhd_central = 25000,
approach_risk = "relative_risk",
erf_shape = "log_linear",
rr_central = 1.118,
rr_increment = 10
)
scenario_A$health_main$impact # Attributable impact in scenario A
#> [1] 1050.86
## Modify scenario (adjust exposure value)
scenario_B <- attribute_mod(
output_attribute = scenario_A,
exp_central = 6 # EXPOSURE 2
)
scenario_B$health_main$impact # Attributable impact in scenario B
#> [1] 277.304