| cba | R Documentation |
This function performs a cost-benefit analysis. It is assumed that the benefit is caused by the positive health impacts of a policy intervention, which generates some costs.
cba(
output_attribute = NULL,
impact_benefit = NULL,
valuation,
cost,
discount_rate_benefit = NULL,
discount_rate_cost = NULL,
inflation_rate = NULL,
real_growth_rate = NULL,
discount_shape = "exponential",
n_years_benefit = 1,
n_years_cost = 0
)
output_attribute |
|
impact_benefit |
|
valuation |
|
cost |
|
discount_rate_benefit, discount_rate_cost |
|
inflation_rate |
|
real_growth_rate |
|
discount_shape |
|
n_years_benefit, n_years_cost |
|
Methodology
This function provides as output three types of cost-benefit indicators \insertCiteBoardman2018_bookhealthiar:
net benefit
cost-benefit ratio
return of investment
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
This function returns a list containing:
1) cba_main (tibble) containing the main CBA results;
net_benefit (numeric column) containing the difference between benefit and cost (i.e. benefit - cost)
benefit (numeric column) containing discounted benefit (i.e. monetized attributable health impact)
cost (numeric column) containing discounted cost
And many more
2) cba_detailed (list) containing detailed (and interim) results.
benefit (list)
cost (tibble)
If the argument output_attribute was specified, then the two results elements are added to the existing output.
Alberto Castro & Axel Luyten
Upstream: attribute_health
Alternative: monetize
# Goal: performs a cost-benefit analysis using an existing output
# of a attribute_... function
output_attribute <- attribute_health(
erf_shape = "log_linear",
rr_central = 1.369,
rr_increment = 10,
exp_central = 8.85,
cutoff_central = 5,
bhd_central = 30747
)
results <- cba(
output_attribute = output_attribute,
valuation = 50000,
cost = 100000000,
discount_shape = "exponential",
discount_rate_benefit = 0.03,
discount_rate_cost = 0.03,
n_years_benefit = 5,
n_years_cost = 5
)
results$cba_main |>
dplyr::select(benefit, cost, net_benefit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.