View source: R/collapse_df_by_group.R
| collapse_df_by_group | R Documentation |
This function paste rows with different values and keep only unique rows following grouping columns
collapse_df_by_group(
df,
group_col_names,
multi_value_col_names = NULL,
ci_col_names = NULL,
only_unique_rows = TRUE
)
df |
|
group_col_names |
|
multi_value_col_names |
|
ci_col_names |
|
only_unique_rows |
|
This function returns a data frame or tibble with lower number rows after collapsing
Alberto Castro & Axel Luyten
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.