| discount | R Documentation |
This function calculates discounted health impacts (without valuation).
discount(
output_attribute = NULL,
impact = NULL,
discount_rate = NULL,
n_years = NULL,
discount_shape = NULL
)
output_attribute |
|
impact |
|
discount_rate |
|
n_years |
|
discount_shape |
|
Methodology
This function applies a discount to attributable health impacts into the future.
One of the following three discount shapes can be selected:
Exponential \insertCiteFrederick2002_jelhealthiar
Hyperbolic as \insertCiteHarvey1986_ms;textualhealthiar
Hyperbolic as \insertCiteMazur1987_book;textualhealthiar
Burden of disease studies may be interested in calculating + discounted health impacts over time, and these may also be used in economic evaluation models, where benefits are not monetized. For this specific purpose, this function is offered.
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
This function returns a list containing:
1) monetization_main (tibble) containing the main monetized results;
monetized_impact (numeric column)
discount_factor (numeric column) calculated based on the entered discount_rate
And many more
2) monetization_detailed (list) containing detailed (and interim) results.
results_by_year (tibble)
health_raw (tibble) containing the monetized results for each for each combination of input uncertainty that were provided to the initial attribute_health() call
If the argument output_attribute was specified, then the two results elements are added to the existing output.
Alberto Castro & Axel Luyten
Upstream: attribute_health, attribute_health
Alternative: monetize
# Goal: discount attributable health impacts
results <- discount(
impact = 20000,
discount_shape = "exponential",
discount_rate = 0.03,
n_years = 20
)
results$monetization_main$monetized_impact
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.