This function calculates discounted health impacts (without valuation).
discount(
output_attribute = NULL,
impact = NULL,
discount_rate = NULL,
n_years = NULL,
discount_shape = NULL
)This function returns a list containing:
1) monetization_main (tibble) containing the main monetized results;
monetized_impact (numeric column)
discount_factor (numeric column) calculated based on the entered discount_rate
And many more
2) monetization_detailed (list) containing detailed (and interim) results.
results_by_year (tibble)
health_raw (tibble) containing the monetized results for each for each combination of input uncertainty that were provided to the initial attribute_health() call
If the argument output_attribute was specified, then the two results elements are added to the existing output.
List produced by healthiar::attribute_health(), healthiar::attribute_lifetable() or healthiar::compare() as results.
Numberic value referring to the health impacts to be monetized (without attribute function). If a Numberic vector is entered multiple assessments (by year) will be carried out. Be aware that the value for year 0 (current) must be entered, while n_years does not include the year 0. Thus, length of impact = n_years + 1.
Numeric value showing the discount rate for future years.
Numeric value referring to number of years in the future to be considered in the discounting and/or inflation. Be aware that the year 0 (without discounting/inflation, i.e. the present) is not be counted here. If a vector is entered in the argument impact, n_years does not need to be entered (length of impact = n_years + 1).
String referring to the assumed equation for the discount factor. By default: "exponential". Otherwise: "hyperbolic_harvey_1986" or "hyperbolic_mazur_1987".
Alberto Castro & Axel Luyten
Methodology
This function applies a discount to attributable health impacts into the future.
One of the following three discount shapes can be selected:
Exponential Frederick2002_jelhealthiar
Hyperbolic as Harvey1986_ms;textualhealthiar
Hyperbolic as Mazur1987_book;textualhealthiar
Burden of disease studies may be interested in calculating + discounted health impacts over time, and these may also be used in economic evaluation models, where benefits are not monetized. For this specific purpose, this function is offered.
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
Upstream: attribute_health, attribute_health
Alternative: monetize
# Goal: discount attributable health impacts
results <- discount(
impact = 20000,
discount_shape = "exponential",
discount_rate = 0.03,
n_years = 20
)
results$monetization_main$monetized_impact
Run the code above in your browser using DataLab