Learn R Programming

healthiar (version 0.2.3)

find_joining_columns: Find joining columns

Description

This function finds columns in two data frames that have same name and identical values (excluding exceptions).- The resulting joining columns are used to dplyr::x_join data frames and add the vector to by=.

Usage

find_joining_columns(df_1, df_2, except = NULL)

Value

This function returns a vector of strings

Arguments

df_1

First Data frame

df_2

Second Data frame

except

Vector of strings showing columns that have to be excluded although they fulfill the inclusion criteria (same name and value)

Author

Alberto Castro & Axel Luyten