View source: R/find_multi_value_col_names.R
| find_multi_value_col_names | R Documentation |
This function find data frame or tibble column names with different values in their rows (i.e. not a unique value)
find_multi_value_col_names(df, group_col_names = NULL)
df |
|
group_col_names |
|
This function returns a string vector with the names of the columns with multiple values
Alberto Castro & Axel Luyten
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.