Learn R Programming

healthiar (version 0.2.3)

find_multi_value_col_names: Find columns with multiple values

Description

This function find data frame or tibble column names with different values in their rows (i.e. not a unique value)

Usage

find_multi_value_col_names(df, group_col_names = NULL)

Value

This function returns a string vector with the names of the columns with multiple values

Arguments

df

Data frame or tibble containing the data

group_col_names

String vector that refers to the column names in df that serve as grouping columns.

Author

Alberto Castro & Axel Luyten