This function find data frame or tibble column names with different values in their rows (i.e. not a unique value)
find_multi_value_col_names(df, group_col_names = NULL)This function returns a string vector with the names of the columns with multiple values
Data frame or tibble containing the data
String vector that refers to the column names in df that serve as grouping columns.
Alberto Castro & Axel Luyten