get_discount_factor: Get discount factor

View source: R/get_discount_factor.R

get_discount_factorR Documentation

Get discount factor

Description

This function calculates the discount factor based on discount rate.

Usage

get_discount_factor(discount_rate, n_years, discount_shape = "exponential")

Arguments

discount_rate

Numeric value showing the discount rate for future years.

n_years

Numeric value referring to number of years in the future to be considered in the discounting and/or inflation. Be aware that the year 0 (without discounting/inflation, i.e. the present) is not be counted here. If a vector is entered in the argument impact, n_years does not need to be entered (length of impact = n_years + 1).

discount_shape

String referring to the assumed equation for the discount factor. By default: "exponential". Otherwise: "hyperbolic_harvey_1986" or "hyperbolic_mazur_1987".

Details

Methodology

This function is called inside monetize().

One of the following three discount shapes can be selected:

  • Exponential \insertCiteFrederick2002_jelhealthiar

  • Hyperbolic as \insertCiteHarvey1986_ms;textualhealthiar

  • Hyperbolic as \insertCiteMazur1987_book;textualhealthiar

Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:

Value

This function returns the numeric discount factor.

Author(s)

Alberto Castro & Axel Luyten

References

\insertAllCited

See Also

  • Alternative: monetize

Examples

get_discount_factor(
  discount_rate = 0.07,
  n_years = 5
 )



healthiar documentation built on March 12, 2026, 5:07 p.m.