View source: R/get_discount_factor.R
| get_discount_factor | R Documentation |
This function calculates the discount factor based on discount rate.
get_discount_factor(discount_rate, n_years, discount_shape = "exponential")
discount_rate |
|
n_years |
|
discount_shape |
|
Methodology
This function is called inside monetize().
One of the following three discount shapes can be selected:
Exponential \insertCiteFrederick2002_jelhealthiar
Hyperbolic as \insertCiteHarvey1986_ms;textualhealthiar
Hyperbolic as \insertCiteMazur1987_book;textualhealthiar
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
This function returns the numeric discount factor.
Alberto Castro & Axel Luyten
Alternative: monetize
get_discount_factor(
discount_rate = 0.07,
n_years = 5
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.