| get_impact | R Documentation |
This function calculates the health impacts for each uncertainty and geo area.
get_impact(input_table, pop_fraction_type)
input_table |
|
TBD. E.g. This function returns a data.frame with one row for each value of the
concentration-response function (i.e. central, lower and upper bound confidence interval.
Moreover, the data frame includes columns such as:
Attributable fraction
Health impact
Outcome metric
And many more.
Alberto Castro & Axel Luyten
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.