Learn R Programming

healthiar (version 0.2.3)

get_impact: Attributable health cases based on relative risk

Description

This function calculates the health impacts for each uncertainty and geo area.

Usage

get_impact(input_table, pop_fraction_type)

Value

TBD. E.g. This function returns a data.frame with one row for each value of the concentration-response function (i.e. central, lower and upper bound confidence interval. Moreover, the data frame includes columns such as:

  • Attributable fraction

  • Health impact

  • Outcome metric

  • And many more.

Arguments

input_table

Data frame containing all input data.

Author

Alberto Castro & Axel Luyten