This function calculates the health impacts for each uncertainty and geo area.
get_impact(input_table, pop_fraction_type)TBD. E.g. This function returns a data.frame with one row for each value of the
concentration-response function (i.e. central, lower and upper bound confidence interval.
Moreover, the data frame includes columns such as:
Attributable fraction
Health impact
Outcome metric
And many more.
Data frame containing all input data.
Alberto Castro & Axel Luyten