get_inflation_factor: Get inflation factor

View source: R/get_inflation_factor.R

get_inflation_factorR Documentation

Get inflation factor

Description

This function calculates the inflation factor based on inflation rate.

Usage

get_inflation_factor(n_years, inflation_rate = NULL, is_deflation = FALSE)

Arguments

n_years

Numeric value referring to number of years in the future to be considered in the discounting and/or inflation. Be aware that the year 0 (without discounting/inflation, i.e. the present) is not be counted here. If a vector is entered in the argument impact, n_years does not need to be entered (length of impact = n_years + 1).

inflation_rate

Numeric value between 0 and 1 referring to the annual inflation (increase of prices). This value is used to adjust monetization for inflation (converting nominal into real values by appyling a deflator). If this adjustment for inflation is not needed leave this argument empty (default value = NULL).

is_deflation

Boolean value (TRUE vs. FALSE) referring to the type of inflation factor. FALSE (default) means inflate present values to future nominal values, while TRUE means deflate future nominal values to present real values

Details

Methodology

This function is called inside monetize().

It calculates the inflation factor based on the inflation rate and the number of years into the future as described in \insertCiteBrealey2023_book;textualhealthiar.

Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:

Value

This function returns the numeric inflation factor.

Author(s)

Alberto Castro & Axel Luyten

References

\insertAllCited

See Also

  • Alternative: monetize

Examples

get_inflation_factor(
  inflation_rate = 0.02,
  n_years = 5
)



healthiar documentation built on March 12, 2026, 5:07 p.m.