View source: R/get_inflation_factor.R
| get_inflation_factor | R Documentation |
This function calculates the inflation factor based on inflation rate.
get_inflation_factor(n_years, inflation_rate = NULL, is_deflation = FALSE)
n_years |
|
inflation_rate |
|
is_deflation |
|
Methodology
This function is called inside monetize().
It calculates the inflation factor based on the inflation rate and the number of years into the future as described in \insertCiteBrealey2023_book;textualhealthiar.
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
This function returns the numeric inflation factor.
Alberto Castro & Axel Luyten
Alternative: monetize
get_inflation_factor(
inflation_rate = 0.02,
n_years = 5
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.