This function calculates the inflation factor based on inflation rate.
Arguments
- n_years
Numeric valuereferring to number of years in the future to be considered in the discounting and/or inflation. Be aware that the year 0 (without discounting/inflation, i.e. the present) is not be counted here. If a vector is entered in the argument impact, n_years does not need to be entered (length of impact = n_years + 1).- inflation_rate
Numeric valuebetween 0 and 1 referring to the annual inflation (increase of prices). This value is used to adjust monetization for inflation (converting nominal into real values by appyling a deflator). Alternatively, anumeric vectorof year-specific rates can be entered (at least as many values as years to be considered, the first value referring to the first year after the present), assuming then that inflation varies over time instead of being constant. If this adjustment for inflation is not needed leave this argument empty (default value = NULL).- is_deflation
Boolean value(TRUE vs. FALSE) referring to the type of inflation factor. FALSE (default) means inflate present values to future nominal values, while TRUE means deflate future nominal values to present real values
Details
Methodology
This function is called inside monetize().
It calculates the inflation factor based on the inflation rate and the number of years into the future as described in Brealey et al. (2023) .
If inflation_rate contains one single value,
inflation is assumed to be constant over time and
the inflation factor increases exponentially with the number of years.
If inflation_rate contains a vector of year-specific rates,
the inflation factor is the product of the year-specific factors,
which better reflects that inflation varies over time.
In that case, inflation_rate must contain
at least as many values as years to be considered (n_years),
the first value referring to the first year after the present.
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
References
Brealey RA, Myers SC, Allen F, Benninga S, Read J (2023). Principles of Corporate Finance, 14th edition. McGraw-Hill Education, New York, NY. ISBN 978-1264117464.
See also
Alternative:
monetize
Examples
# Constant inflation rate
get_inflation_factor(
inflation_rate = 0.02,
n_years = 5
)
#> [1] 1.104081
# Year-specific inflation rates
get_inflation_factor(
inflation_rate = c(0.02, 0.03, 0.05, 0.04, 0.02),
n_years = 5
)
#> [1] 1.1702