View source: R/get_input_args.R
| get_input_args | R Documentation |
This function compiles the input data of the main function and calculates the population attributable fraction based on the input data (all in one data frame)
get_input_args(environment, call)
This function returns a list with all input data together by argument
Alberto Castro & Axel Luyten
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.