This function distributes and store outputs by level of detail by aggregating or filtering impacts.
get_output(
input_args = NULL,
input_table = NULL,
intermediate_calculations = NULL,
results_raw
)TBD. E.g. This function returns a data.frame with one row for each value of the
concentration-response function (i.e. central, lower and upper bound confidence interval.
Moreover, the data frame includes columns such as:
Attributable fraction
Health impact
Outcome metric
And many more.
List containingall arguments and values entered in attribute().
Tibble containing the input_table data compiled and packed in a data frame.
Tibble containing intermediate calculations (e.g. from life table pathway).
Tibble containing all the calculation of health impacts.
Alberto Castro & Axel Luyten