| get_paf | R Documentation |
This function calculates the population attributable fraction (PAF) of a health outcome due to exposure to an environmental stressor
get_paf(rr_at_exp, prop_pop_exp)
rr_at_exp |
|
prop_pop_exp |
|
Methodology
This function is called internally inside other healthiar functions, e.g. attribute_health().
The function calculates the population attributable fraction
(i.e. the percent of health cases that are attributable to the exposure)
based on the relative risk as described in the extensive existing literature
\insertCiteWHO2003_reporthealthiar.
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
This function returns the population attributable fraction as a numeric value.
Alberto Castro & Axel Luyten
Alternative: attribute_health, attribute_lifetable
# Goal: calculate PAF based on RR and the proportion of population exposed
get_paf(rr = 1.062, prop_pop_exp = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.