Learn R Programming

healthiar (version 0.2.3)

get_paf: Get population attributable fraction

Description

This function calculates the population attributable fraction (PAF) of a health outcome due to exposure to an environmental stressor

Usage

get_paf(rr_at_exp, prop_pop_exp)

Value

This function returns the population attributable fraction as a numeric value.

Arguments

rr_at_exp

Numerical value Risk estimate of the concentration response function for a specific concentration. The population attributable fraction is normally calculated using the risk estimate that refers to the concentration that reflects the population exposure and the cut-off. This risk estimate is obtained after re-scaling from the epidemiological study with a particular increment (e.g. for PM2.5 10 or 5 ug/m3) to the aimed concentration.

prop_pop_exp

Numeric value or numeric vector specifying the population fraction(s) exposed for each exposure (category). Default: 1. See Details for more info. Only applicable in RR pathways.

Author

Alberto Castro & Axel Luyten

Details

Methodology

This function is called internally inside other healthiar functions, e.g. attribute_health(). The function calculates the population attributable fraction (i.e. the percent of health cases that are attributable to the exposure) based on the relative risk as described in the extensive existing literature WHO2003_report,Steenland2006-e,Lehtomaki_2025_ehhealthiar.

Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:

References

See Also

  • Alternative: attribute_health, attribute_lifetable

Examples

Run this code

# Goal: calculate PAF based on RR and the proportion of population exposed
get_paf(rr = 1.062, prop_pop_exp = 1)


Run the code above in your browser using DataLab