| get_pif | R Documentation |
This function calculates the potential impact fraction of a health outcome due to exposure to an environmental stressor
get_pif(rr_at_exp_1, rr_at_exp_2, prop_pop_exp_1, prop_pop_exp_2)
rr_at_exp_1 |
|
rr_at_exp_2 |
|
prop_pop_exp_1 |
|
prop_pop_exp_2 |
|
Methodology
This function is internally used inside the healthiar function compare().
The potential impact fraction (PIF) is calculated as
described in \insertCiteWHO2003_report;textualhealthiar,
\insertCiteMurray2003_spbm;textualhealthiar and
\insertCiteAskari2020_ijph;textualhealthiar.
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
This function returns the potential impact fraction as a numeric value.
Alberto Castro & Axel Luyten
Alternative: compare
# Goal: calculate the potential impact fraction (PIF)
results <- get_pif(
rr_at_exp_1 = 1.043879,
rr_at_exp_2 = 1.011217,
prop_pop_exp_1 = 1,
prop_pop_exp_2 = 1
)
print(results)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.