This function returns the potential impact fraction as a numeric value.
Arguments
rr_at_exp_1
Numerical value showing the risk estimate of the concentration response function for a specific concentration in the scenario 1. The population attributable fraction is normally calculated using the risk estimate that refers to the concentration that reflects the population exposure and the cut-off. This risk estimate is obtained after re-scaling from the epidemiological study with a particular increment (e.g. for PM2.5 10 or 5 ug/m3) to the aimed concentration.
rr_at_exp_2
Numerical value showing the risk estimate of the concentration response function for a specific concentration in the scenario 2. The population attributable fraction is normally calculated using the risk estimate that refers to the concentration that reflects the population exposure and the cut-off. This risk estimate is obtained after re-scaling from the epidemiological study with a particular increment (e.g. for PM2.5 10 or 5 ug/m3) to the aimed concentration.
prop_pop_exp_1
Numerical value showing the fraction ([0,1]) of population exposed to the environmental stressor in the scenario 1. Per default = 1 (i.e. 100% of population is exposed).
prop_pop_exp_2
Numerical value showing the fraction ([0,1]) of population exposed to the environmental stressor in the scenario 1. Per default = 1 (i.e. 100% of population is exposed).
Author
Alberto Castro & Axel Luyten
Details
Methodology
This function is internally used inside the healthiar function compare().
The potential impact fraction (PIF) is calculated as
described in WHO2003_report;textualhealthiar,
Murray2003_spbm;textualhealthiar and
Askari2020_ijph;textualhealthiar.
Detailed information about the methodology (including equations)
is available in the package vignette.
More specifically, see chapters: