View source: R/get_risk_and_pop_fraction.R
| get_risk_and_pop_fraction | R Documentation |
This function calculates the population attributable fraction (PAF) based on the input data and puts the results in additional columns joined to the input data frame.
get_risk_and_pop_fraction(input_table, pop_fraction_type)
input_table |
|
pop_fraction_type |
|
This function returns a data.frame with the input data adding a column for the population attributable fraction
Moreover, the data frame includes columns such as:
Attributable fraction
Health impact
Outcome metric
And many more.
Alberto Castro & Axel Luyten
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.