| monetize | R Documentation |
This function monetizes health impacts
monetize(
output_attribute = NULL,
impact = NULL,
valuation,
discount_rate = NULL,
discount_shape = "exponential",
n_years = NULL,
inflation_rate = NULL,
real_growth_rate = NULL,
info = NULL
)
output_attribute |
|
impact |
|
valuation |
|
discount_rate |
|
discount_shape |
|
n_years |
|
inflation_rate |
|
real_growth_rate |
|
info |
|
Methodology
This function monetize health impacts valuating them and applying discounting \insertCiteFrederick2002_jelhealthiar and considering inflation \insertCiteBrealey2023_bookhealthiar.
If the monetized values require adjustment for inflation,
a deflator based on inflation_rate can be applied
\insertCiteHMTreasury2022_greenbookhealthiar.
If the monetized values require adjustment for base valuation upward,
a factor based valuation growth can be applied
\insertCiteOECD2012_bookhealthiar.
One of the following three discount shapes can be selected:
Exponential \insertCiteFrederick2002_jelhealthiar
Hyperbolic as \insertCiteHarvey1986_ms;textualhealthiar
Hyperbolic as \insertCiteMazur1987_book;textualhealthiar
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
This function returns a list containing:
1) monetization_main (tibble) containing the main monetized results;
monetized_impact (numeric column)
discount_factor (numeric column) calculated based on the entered discount_rate
And many more
2) monetization_detailed (list) containing detailed (and interim) results.
results_by_year (tibble)
health_raw (tibble) containing the monetized results for each for each combination of input uncertainty that were provided to the initial attribute_health() call
If the argument output_attribute was specified, then the two results elements are added to the existing output.
Alberto Castro & Axel Luyten
Upstream: attribute_health, attribute_lifetable, compare
Alternative: get_inflation_factor,
get_discount_factor, cba
# Goal: monetize the attributable impacts of an existing healthiar
# assessment
output_attribute <- attribute_health(
erf_shape = "log_linear",
rr_central = exdat_pm$relative_risk,
rr_increment = 10,
exp_central = exdat_pm$mean_concentration,
cutoff_central = exdat_pm$cut_off_value,
bhd_central = exdat_pm$incidence
)
results <- monetize(
output_attribute = output_attribute,
discount_shape = "exponential",
discount_rate = 0.03,
n_years = 5,
valuation = 50000 # E.g. EURO
)
# Attributable COPD cases its monetized impact
results$monetization_main |>
dplyr::select(impact, monetized_impact)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.