Learn R Programming

healthiar (version 0.2.4)

monetize: Monetize health impacts

Description

This function monetizes health impacts

Usage

monetize(
  output_attribute = NULL,
  impact = NULL,
  valuation,
  discount_rate = NULL,
  discount_shape = "exponential",
  n_years = NULL,
  inflation_rate = NULL,
  real_growth_rate = NULL,
  info = NULL
)

Value

This function returns a list containing:

1) monetization_main (tibble) containing the main monetized results;

  • monetized_impact (numeric column)

  • discount_factor (numeric column) calculated based on the entered discount_rate

  • And many more

2) monetization_detailed (list) containing detailed (and interim) results.

  • results_by_year (tibble)

  • health_raw (tibble) containing the monetized results for each for each combination of input uncertainty that were provided to the initial attribute_health() call

If the argument output_attribute was specified, then the two results elements are added to the existing output.

Arguments

output_attribute

List produced by healthiar::attribute_health(), healthiar::attribute_lifetable() or healthiar::compare() as results.

impact

Numberic value referring to the health impacts to be monetized (without attribute function). If a Numberic vector is entered multiple assessments (by year) will be carried out. Be aware that the value for year 0 (current) must be entered, while n_years does not include the year 0. Thus, length of impact = n_years + 1.

valuation

Numberic value referring to unit value of a health impact.

discount_rate

Numeric value showing the discount rate for future years.

discount_shape

String referring to the assumed equation for the discount factor. By default: "exponential". Otherwise: "hyperbolic_harvey_1986" or "hyperbolic_mazur_1987".

n_years

Numeric value referring to number of years in the future to be considered in the discounting and/or inflation. Be aware that the year 0 (without discounting/inflation, i.e. the present) is not be counted here. If a vector is entered in the argument impact, n_years does not need to be entered (length of impact = n_years + 1).

inflation_rate

Numeric value between 0 and 1 referring to the annual inflation (increase of prices). This value is used to adjust monetization for inflation (converting nominal into real values by appyling a deflator). If this adjustment for inflation is not needed leave this argument empty (default value = NULL).

real_growth_rate

Numeric value between 0 and 1 referring to the annual real-term appreciation in the societal value of health (e.g., income elasticity). This adjusts the valuation upward to reflect rising wealth, independent of general price inflation.

info

String, data frame or tibble providing information about the assessment. Only attached if impact is entered by the users. If output_attribute is entered, use info in that function or add the column manually. Optional argument.

Author

Alberto Castro & Axel Luyten

Details

Methodology

This function monetize health impacts valuating them and applying discounting Frederick2002_jelhealthiar and considering inflation Brealey2023_bookhealthiar.

If the monetized values require adjustment for inflation, a deflator based on inflation_rate can be applied HMTreasury2022_greenbookhealthiar.

If the monetized values require adjustment for base valuation upward, a factor based valuation growth can be applied OECD2012_bookhealthiar.

One of the following three discount shapes can be selected:

  • Exponential Frederick2002_jelhealthiar

  • Hyperbolic as Harvey1986_ms;textualhealthiar

  • Hyperbolic as Mazur1987_book;textualhealthiar

Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:

References

See Also

  • Upstream: attribute_health, attribute_lifetable, compare

  • Alternative: get_inflation_factor, get_discount_factor, cba

Examples

Run this code
# Goal: monetize the attributable impacts of an existing healthiar
# assessment
output_attribute <- attribute_health(
erf_shape = "log_linear",
rr_central = exdat_pm$relative_risk,
rr_increment = 10,
exp_central = exdat_pm$mean_concentration,
cutoff_central = exdat_pm$cut_off_value,
bhd_central = exdat_pm$incidence
)

results <- monetize(
  output_attribute = output_attribute,
  discount_shape = "exponential",
  discount_rate = 0.03,
  n_years = 5,
  valuation = 50000 # E.g. EURO
)

# Attributable COPD cases its monetized impact
results$monetization_main |>
  dplyr::select(impact, monetized_impact)


Run the code above in your browser using DataLab