| multiexpose | R Documentation |
This function aggregates health impacts from multiple exposures to environmental stressors.
multiexpose(
output_attribute_exp_1,
output_attribute_exp_2,
exp_name_1,
exp_name_2,
approach_multiexposure = "additive"
)
output_attribute_exp_1, output_attribute_exp_2 |
Output of attribute() for exposure 1 and 2, respectively. Baseline health data and population must be identical in outputs 1 and 2. |
exp_name_1, exp_name_2 |
|
approach_multiexposure |
|
Methodology
This function can add up the attributable health impacts from correlated exposures applying one of the following methods \insertCiteStrak2024_reporthealthiar:
Additive \insertCiteSteenland2006-ehealthiar
Multiplicative \insertCiteJerrett2013-ouphealthiar
Combined \insertCiteSteenland2006-ehealthiar
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
This function returns a list containing:
1) health_main (tibble) containing the main results;
impact (numeric column) attributable health burden/impact
pop_fraction (numeric column) population attributable fraction; only applicable in relative risk assessments
And many more
2) health_detailed (list) containing detailed (and interim) results.
input_args (list) containing all the argument inputs used in the background
input_table (tibble) containing the inputs after preparation
results_raw (tibble) containing results for all combinations of input (geo units, uncertainty, age and sex specific data...)
results_by_... (tibble) containing results stratified by each geographic unit, age or sex.
Alberto Castro & Axel Luyten
Upstream: attribute_health, attribute_lifetable
# Goal: determine aggregated health impacts from multiple exposures
# Step 1: create assessment with exposure 1
output_attribute_exp_1 <- attribute_health(
erf_shape = "log_linear",
rr_central = 1.369,
rr_increment = 10,
exp_central = 8.85,
cutoff_central = 5,
bhd_central = 30747
)
output_attribute_exp_1$health_main$impact
# Step 2: create assessment with exposure 2
output_attribute_exp_2 <- attribute_mod(
output_attribute = output_attribute_exp_1,
exp_central = 10.9,
rr_central = 1.031
)
output_attribute_exp_2$health_main$impact
# Step 3: aggregate impacts of the two assessments
results <- multiexpose(
output_attribute_exp_1 = output_attribute_exp_1,
output_attribute_exp_2 = output_attribute_exp_2,
exp_name_1 = "pm2.5",
exp_name_2 = "no2",
approach_multiexposure = "multiplicative"
)
results$health_main$impact
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.