prepare_lifetable: Convert multi-year life table to single year life table

View source: R/prepare_lifetable.R

prepare_lifetableR Documentation

Convert multi-year life table to single year life table

Description

This function determines populations and deaths by one year age groups.

Usage

prepare_lifetable(age_group, population, bhd)

Arguments

age_group

Numeric vector referring to the first years of the age groups. E.g. c(0, 20, 40, 60) means [0, 20), [20, 40), [40, 60), [60, )

population

Numeric vector referring to mid-year populations by age group.

bhd

Numeric vector referring to the baseline health data (deaths) by age group.

Details

Methodology

The conversion follows the methodology of the WHO tool. See the AirQ+ manual "Health impact assessment of air pollution: AirQ+ life table manual" for guidance on how to convert larger age groups to 1 year age groups, section "Estimation of yearly values" \insertCiteWHO2020_reporthealthiar.

Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:

Value

This function returns a tibble containing the columns:

  • population_for_attribute (numeric) containing population values for each age

  • bhd_for_attribute (numeric) containing baseline health data values for each age

  • and more columns containing input data or results

Author(s)

Alberto Castro & Axel Luyten

References

\insertAllCited

See Also

  • Downstream: attribute_lifetable

Examples

# Goal: Convert 5-year population and death data into single year life table
results <- prepare_lifetable(
  age_group = c(0, 5, 10, 15),
  population = c(3387900, 3401300, 3212300, 3026100),
  bhd = c(4727, 472, 557, 1323)
)



healthiar documentation built on March 12, 2026, 5:07 p.m.