View source: R/prepare_lifetable.R
| prepare_lifetable | R Documentation |
This function determines populations and deaths by one year age groups.
prepare_lifetable(age_group, population, bhd)
age_group |
|
population |
|
bhd |
|
Methodology
The conversion follows the methodology of the WHO tool. See the AirQ+ manual "Health impact assessment of air pollution: AirQ+ life table manual" for guidance on how to convert larger age groups to 1 year age groups, section "Estimation of yearly values" \insertCiteWHO2020_reporthealthiar.
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
This function returns a tibble containing the columns:
population_for_attribute (numeric) containing population values for each age
bhd_for_attribute (numeric) containing baseline health data values for each age
and more columns containing input data or results
Alberto Castro & Axel Luyten
Downstream: attribute_lifetable
# Goal: Convert 5-year population and death data into single year life table
results <- prepare_lifetable(
age_group = c(0, 5, 10, 15),
population = c(3387900, 3401300, 3212300, 3026100),
bhd = c(4727, 472, 557, 1323)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.