Convert multi-year life table to single year life table
Source:R/prepare_lifetable.R
prepare_lifetable.RdThis function determines populations and deaths by one year age groups.
Value
This function returns a tibble containing the columns:
population_for_attribute(numeric) containing population values for each agebhd_for_attribute(numeric) containing baseline health data values for each ageand more columns containing input data or results
Details
Methodology
The conversion follows the methodology of the WHO tool. See the AirQ+ manual "Health impact assessment of air pollution: AirQ+ life table manual" for guidance on how to convert larger age groups to 1 year age groups, section "Estimation of yearly values" (WHO 2020) .
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
References
WHO (2020). “Health impact assessment of air pollution: AirQ+ life table manual.” World Health Organization - Regional Office for Europe. https://www.who.int/europe/publications/i/item/WHO-EURO-2020-1559-41310-56212.
See also
Downstream:
attribute_lifetable