| standardize | R Documentation |
This function obtains age-standardized health impacts based on multiple age-group specific assessments
standardize(output_attribute, age_group, ref_prop_pop = NULL)
output_attribute |
|
age_group |
|
ref_prop_pop |
|
Methodology
This function applies the direct method of standardization, where the age-specific rates observed in a study population are applied to a standard (reference) population distribution.
For age standardization in health impact assessments, the World Health Organization \insertCiteAhmad2001_reporthealthiar and the Global Burden of Disease study \insertCiteGBD2020_tldemohealthiar provide the relevant information on this topic.
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
This function works after running attribute_health() or attribute_lifetable() functions.
If you want to use it in combination with compare(),
please standardize first the results of attribute functions and then compare.
This function returns a list containing:
1) health_main (tibble) containing the age-standardized main results;
2) health_detailed (tibble) containing the results per age group.
Alberto Castro & Axel Luyten
Upstream:
attribute_health, attribute_lifetable
# Goal: age-standardize two age group-specific impacts
output_attribute <- attribute_health(
rr_central = 1.063,
rr_increment = 10,
erf_shape = "log_linear",
cutoff_central = 0,
age_group = c("below_40", "above_40"),
exp_central = c(8.1, 10.9),
bhd_central = c(1000, 4000),
population = c(100000, 500000)
)
results <- standardize(
output_attribute = output_attribute,
age_group = c("below_40", "above_40"),
ref_prop_pop = c(0.5, 0.5)
)
results$health_detailed$results_raw$impact_per_100k_inhab # age group-specific impact rate
results$health_main$impact_per_100k_inhab # age-standardized impact rate
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.