View source: R/summarize_uncertainty.R
| summarize_uncertainty | R Documentation |
This function obtains a summary of uncertainty (based on central, lower and upper estimates of at least one input variable) using a Monte Carlo simulation.
Input variables that will be processed are:
relative_risk (rr_...)
exposure (exp_...)
cutoff (cutoff_...)
baseline health data (bhd_...)
disability weight (dw_...)
duration (duration_...)
summarize_uncertainty(output_attribute, n_sim, seed = NULL)
output_attribute |
|
n_sim |
|
seed |
|
Function arguments
seed
If the seed argument is specified then the parallel package
is used to generate independent L’Ecuyer random number streams.
One stream is allocated per variable (or per variable–geography combination, as needed),
ensuring reproducible and independent random draws across variables and scenarios.
Methodology
This function summarizes the uncertainty of the attributable health impacts (i.e. a single confidence interval instead of many combinations). For this purpose, it employs a Monte Carlo simulation methodology \insertCiteRobert2004_bookhealthiar and framework application \insertCiteRubinstein2016_bookhealthiar.
Detailed information about the methodology (including equations) is available in the package vignette. More specifically, see chapters:
This function returns a list containing:
1) uncertainty_main (tibble) containing the numeric
summary uncertainty central estimate and corresponding lower and upper confidence intervals
for the attributable health impacts obtained through Monte Carlo simulation;
2) uncertainty_detailed (list) containing detailed (and interim) results.
impact_by_sim (tibble) containing the results for each simulation
uncertainty_by_geo_id_micro (tibble) containing results for each geographic unit under analysis (specified in geo_id_micro argument in the preceding attribute_health call)
The two results elements are added to the existing output.
Alberto Castro & Axel Luyten
Upstream:
attribute_health, attribute_lifetable,
compare
# Goal: obtain summary uncertainty for an existing attribute_health() output
# First create an assessment
attribute_health_output <- attribute_health(
erf_shape = "log_linear",
rr_central = 1.369,
rr_lower = 1.124,
rr_upper = 1.664,
rr_increment = 10,
exp_central = 8.85,
exp_lower = 8,
exp_upper = 10,
cutoff_central = 5,
bhd_central = 30747,
bhd_lower = 28000,
bhd_upper = 32000
)
# Then run Monte Carlo simulation
results <- summarize_uncertainty(
output_attribute = attribute_health_output,
n_sim = 100
)
results$uncertainty_main$impact # Central, lower and upper estimates
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.